import 'package:flutter/material.dart';

class CHDialogConfig {
  static const double radius = 10.0;
  static const double buttonHeight = 50.0;
  static const double buttonFontSize = 15.0;
  static const double loadingSize = 16.0;
  static const double contentPadding = 25.0;
  static const double maxWidth = 285.0;
  static const Color confirmTextColor = const Color(0xff1989fa);
  static const Color cancelTextColor = const Color(0xff323233);
  static const Color borderColor = const Color(0xffebedf0);
  static const Color titleColor = const Color(0xff323233);
  static const Color contentColor = const Color(0xff646566);
  static const String confirmText = 'ok';
  static const String confirmButtonText = '确认';
  static const String cancelButtonText = '取消';
}

///自定义Dialog
class CHDialog extends StatefulWidget {
  // 弹窗标题
  final String? title;

  // 弹窗内容
  final String? message;

  // 标题对齐方式
  final AlignmentDirectional titleAlign;

  // 内容对齐方式
  final TextAlign messageAlign;

  // 是否展示确认按钮
  final bool showConfirmButton;

  // 是否展示取消按钮
  final bool showCancelButton;

  // 确认按钮文案
  final String confirmButtonText;

  // 确认按钮颜色
  final Color confirmButtonColor;

  // 确认按钮文本颜色
  final Color confirmTextColor;

  // 取消按钮文案
  final String cancelButtonText;

  // 取消按钮颜色
  final Color cancelButtonColor;

  // 取消按钮文本颜色
  final Color cancelTextColor;

  // 点击确认按钮时触发
  final Function()? onConfirm;

  // 点击取消按钮时触发
  final Function()? onCancel;

  // 关闭前的回调函数
  final Function()? beforeClose;

  // 自定义内容
  final Widget? child;

  // 背景色
  final Color? background;

  // border
  final Color? borderColor;

  // 标题颜色
  final Color? titleColor;

  // 内容颜色
  final Color? contentColor;

  const CHDialog(
      {Key? key,
      this.title,
      this.message,
      this.titleAlign: AlignmentDirectional.center,
      this.messageAlign: TextAlign.center,
      this.showConfirmButton: true,
      this.showCancelButton: false,
      this.confirmButtonText: CHDialogConfig.confirmButtonText,
      this.confirmButtonColor: Colors.white,
      this.confirmTextColor: CHDialogConfig.confirmTextColor,
      this.cancelButtonText: CHDialogConfig.cancelButtonText,
      this.cancelButtonColor: Colors.white,
      this.cancelTextColor: CHDialogConfig.cancelTextColor,
      this.onConfirm,
      this.onCancel,
      this.beforeClose,
      this.child,
      this.background,
      this.borderColor,
      this.titleColor,
      this.contentColor})
      : super(key: key);

  @override
  _NDialog createState() => _NDialog();
}

class _NDialog extends State<CHDialog> {
  bool _confirmLoading = false;

  confirmDialog() async {
    if (widget.beforeClose != null) {
      setState(() {
        _confirmLoading = true;
      });
      await widget.beforeClose!();
    }
    setState(() {
      _confirmLoading = false;
    });
//    hideDialog();
    Navigator.of(context).pop<String>(CHDialogConfig.confirmText);
    if (widget.onConfirm != null) {
      widget.onConfirm!();
    }
  }

  hideDialog() async {
    if (widget.onCancel != null) {
      widget.onCancel!();
    }
    Navigator.of(context).pop();
  }

  Widget buildCancelButton() {
    return DecoratedBox(
        decoration: BoxDecoration(
            color: widget.cancelButtonColor,
            borderRadius: BorderRadius.only(
                bottomLeft: Radius.circular(CHDialogConfig.radius))),
        child: Material(
            type: MaterialType.transparency,
            child: InkWell(
                onTap: hideDialog,
                borderRadius: BorderRadius.only(
                    bottomLeft: Radius.circular(CHDialogConfig.radius)),
                child: Container(
                    height: CHDialogConfig.buttonHeight,
                    alignment: Alignment.center,
                    child: Text(widget.cancelButtonText,
                        style: TextStyle(
                          fontSize: CHDialogConfig.buttonFontSize,
                          color: widget.cancelTextColor,
                        ))))));
  }

  Widget buildConfirmButton() {
    return DecoratedBox(
        decoration: BoxDecoration(
            color: widget.confirmButtonColor,
            borderRadius: widget.showCancelButton
                ? BorderRadius.only(
                    bottomRight: Radius.circular(CHDialogConfig.radius))
                : BorderRadius.only(
                    bottomLeft: Radius.circular(CHDialogConfig.radius),
                    bottomRight: Radius.circular(CHDialogConfig.radius))),
        child: Material(
          type: MaterialType.transparency,
          child: InkWell(
              onTap: confirmDialog,
              focusColor: _confirmLoading
                  ? Colors.transparent
                  : Theme.of(context).focusColor,
              highlightColor: _confirmLoading
                  ? Colors.transparent
                  : Theme.of(context).highlightColor,
              hoverColor: _confirmLoading
                  ? Colors.transparent
                  : Theme.of(context).hoverColor,
              splashColor: _confirmLoading
                  ? Colors.transparent
                  : Theme.of(context).splashColor,
              borderRadius: widget.showCancelButton
                  ? BorderRadius.only(
                      bottomRight: Radius.circular(CHDialogConfig.radius))
                  : BorderRadius.only(
                      bottomLeft: Radius.circular(CHDialogConfig.radius),
                      bottomRight: Radius.circular(CHDialogConfig.radius)),
              child: Container(
                height: CHDialogConfig.buttonHeight,
                alignment: Alignment.center,
                child: _confirmLoading
                    ? SizedBox(
                        width: CHDialogConfig.loadingSize,
                        height: CHDialogConfig.loadingSize,
                        child: CircularProgressIndicator(
                          valueColor:
                              AlwaysStoppedAnimation(widget.confirmTextColor),
                          backgroundColor: widget.confirmButtonColor,
                          strokeWidth: 1,
                        ),
                      )
                    : Text(widget.confirmButtonText,
                        style: TextStyle(
                          fontSize: CHDialogConfig.buttonFontSize,
                          color: widget.confirmTextColor,
                        )),
              )),
        ));
  }

  Widget buildButtons() {
    return Container(
        child: Row(
      children: <Widget>[
        Expanded(
            child: widget.showCancelButton ? buildCancelButton() : Text(''),
            flex: widget.showCancelButton ? 1 : 0),
        SizedBox(
            width: widget.showCancelButton ? 1 : 0,
            height: CHDialogConfig.buttonHeight,
            child: Container(
                color: widget.borderColor ?? CHDialogConfig.borderColor)),
        Expanded(
            child:
                widget.showConfirmButton ? buildConfirmButton() : Container(),
            flex: widget.showConfirmButton ? 1 : 0),
      ],
    ));
  }

  @override
  Widget build(BuildContext context) {
    Column _buildContent = Column(
      mainAxisSize: MainAxisSize.min,
      children: <Widget>[
        widget.title != null
            ? Container(
                padding: EdgeInsets.fromLTRB(
                    CHDialogConfig.contentPadding,
                    CHDialogConfig.contentPadding,
                    CHDialogConfig.contentPadding,
                    0),
                alignment: widget.titleAlign,
                child: Text(widget.title!,
                    style: TextStyle(
                        fontSize: CHDialogConfig.buttonFontSize,
                        color: widget.titleColor ?? CHDialogConfig.titleColor,
                        fontWeight: FontWeight.w500)),
              )
            : Container(),
        Flexible(
          child: widget.child ??
              Container(
                padding: EdgeInsets.fromLTRB(
                    CHDialogConfig.contentPadding,
                    widget.title != null
                        ? CHDialogConfig.contentPadding / 2
                        : CHDialogConfig.contentPadding,
                    CHDialogConfig.contentPadding,
                    CHDialogConfig.contentPadding),
                child: Text(widget.message!,
                    textAlign: widget.messageAlign,
                    style: TextStyle(
                        fontSize: CHDialogConfig.buttonFontSize,
                        color: widget.contentColor ??
                            CHDialogConfig.contentColor)),
              ),
        ),
        (widget.showConfirmButton || widget.showCancelButton)
            ? SizedBox(
                height: 1,
                child: Container(
                    color: widget.borderColor ?? CHDialogConfig.borderColor))
            : Container(),
        (widget.showConfirmButton || widget.showCancelButton)
            ? buildButtons()
            : Container()
      ],
    );

    return Material(
      type: MaterialType.transparency,
      child: Center(
        child: ConstrainedBox(
          constraints: BoxConstraints(maxWidth: CHDialogConfig.maxWidth),
          child: Container(
            decoration: BoxDecoration(
                color: widget.background ?? Colors.white,
                borderRadius:
                    BorderRadius.circular(CHDialogConfig.radius)),
            child: _buildContent,
          ),
        ),
      ),
    );
  }
}
